from django.urls import path
from .views import (
    ArchiveMainView, ArchiveYearView, ArchiveMonthView, 
    ArchiveDayView
)

app_name = 'django_cs_archive'

urlpatterns = [
    # 1. Erroa: Urteen zerrenda (/archive/)
    path('', ArchiveMainView.as_view(), name='index'),

    # 2. Urtea: Hilabeteen zerrenda (/archive/2025/)
    path('<int:year>/', ArchiveYearView.as_view(), name='year'),
    
    # 3. Hilabetea: Artikulu zerrenda (/archive/2025/03/)
    path('<int:year>/<int:month>/', ArchiveMonthView.as_view(), name='month'),
    
    path('<int:year>/<int:month>/<int:day>/', ArchiveDayView.as_view(), name='day'),
]


# Zure paketean (adibidez models.py)
from django.urls import reverse
from .utils import get_date_field

class ArchiveUrlMixin:
    def get_absolute_url(self):
        date_field_name = get_date_field()
        date_val = getattr(self, date_field_name)
        
        return reverse('archive:detail', kwargs={
            'year': date_val.year,
            'month': date_val.strftime('%m'),
            'day': date_val.strftime('%d'),
            'slug': self.slug  # Suposatzen da ereduak 'slug' daukala
        })


from django.views.generic.dates import (
    ArchiveIndexView, YearArchiveView, MonthArchiveView, 
    DayArchiveView, DateDetailView
)
from .utils import get_archive_model, get_date_field

class DynamicArchiveMixin:
    make_object_list = True
    allow_future = False
    month_format = '%m'

    def get_queryset(self):
        model = get_archive_model()
        return model.objects.all()

    def get_date_field(self):
        return get_date_field()

# 1. BISTA BERRIA: Urteak zerrendatzeko (/archive/)
class ArchiveMainView(DynamicArchiveMixin, ArchiveIndexView):
    date_list_period = 'year'  # Honek urteak aterako ditu 'date_list' aldagaian
    template_name = "django_cs_archive/archive_index.html"

# 2. URTE BISTA: Hilabeteak zerrendatzeko (/archive/2025/)
class ArchiveYearView(DynamicArchiveMixin, YearArchiveView):
    make_object_list = True # Artikuluak ere eskuragarri egongo dira, baina txantiloian hilabeteak erakutsiko ditugu
    template_name = "django_cs_archive/archive_year.html"

# 3. HILABETE BISTA: Artikuluak zerrendatzeko (/archive/2025/03/)
class ArchiveMonthView(DynamicArchiveMixin, MonthArchiveView):
    template_name = "django_cs_archive/archive_month.html"

class ArchiveDayView(DynamicArchiveMixin, DayArchiveView):
    template_name = "django_cs_archive/archive_day.html"



from django.conf import settings
from django.apps import apps
from django.core.exceptions import ImproperlyConfigured

def get_archive_model():
    # Ezarpena: CS_ARCHIVE_MODEL
    model_string = getattr(settings, 'CS_ARCHIVE_MODEL', None)
    if not model_string:
        raise ImproperlyConfigured("CS_ARCHIVE_MODEL ezarri behar da settings.py fitxategian.")
    try:
        return apps.get_model(model_string, require_ready=False)
    except LookupError:
        raise ImproperlyConfigured(f"Ezin da aurkitu eredua: {model_string}")

def get_date_field():
    # Ezarpena: CS_ARCHIVE_DATE_FIELD (Defektuz: 'publish_date')
    return getattr(settings, 'CS_ARCHIVE_DATE_FIELD', 'publish_date')